@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package ember
@@ -37,11 +32,6 @@ type ElementKey struct {
 // ElementCollection contains one level of elements and their Ids as key.
 type ElementCollection map[ElementKey]*Element
 
-// NewElementCollection creates a empty element collection.
-func NewElementCollection() ElementCollection {
-	return make(ElementCollection)
-}
-
 // Populate fills in collection with data from the decoder.
 //
 //nolint:gocyclo,cyclop
@@ -203,6 +193,11 @@ func (ec ElementCollection) MarshalJSON() ([]byte, error) {
 	return bytes, nil
 }
 
+// NewElementConnection creates a empty element collection.
+func NewElementConnection() ElementCollection {
+	return make(ElementCollection)
+}
+
 // GetRootRequest returns a S101 request packet with an encoded request for root collection.
 func GetRootRequest() ([]byte, error) {
 	encoder := asn1.NewEncoder()
